@@ -5,6 +5,7 @@
 #' @template na-handling
 #' @inheritParams checkVector
 #' @template bounds
+#' @template null.ok
 #' @template checker
 #' @family basetypes
 #' @seealso \code{\link{asInteger}}
@@ -14,10 +15,14 @@
 #' testInteger(1L)
 #' testInteger(1.)
 #' testInteger(1:2, lower = 1, upper = 2, any.missing = FALSE)
-checkInteger = function(x, lower = -Inf, upper = Inf, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL) {
-  .Call(c_check_integer, x, lower, upper, any.missing, all.missing, len, min.len, max.len, unique, names)
+checkInteger = function(x, lower = -Inf, upper = Inf, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, null.ok = FALSE) {
+  .Call(c_check_integer, x, lower, upper, any.missing, all.missing, len, min.len, max.len, unique, names, null.ok)
 }
 
+#' @export
+#' @rdname checkInteger
+check_integer = checkInteger
+
 #' @export
 #' @include makeAssertion.R
 #' @template assert
