@@ -9,16 +9,12 @@
 #' @examples
 #' testOS("linux")
 checkOS = function(os) {
-  os.names = c("windows", "mac", "linux", "solaris")
-  ok = match.arg(os, os.names, several.ok = TRUE)
-
-  if (OS %nin% ok)
+  ok = match.arg(os, c("windows", "mac", "linux", "solaris"), several.ok = TRUE)
+  if (.OS %nin% ok)
     return(sprintf("OS must be %s", paste0(ok, collapse = " or ")))
   return(TRUE)
 }
 
-OS = c("windows", "mac", "linux", "solaris")[match(tolower(Sys.info()["sysname"]), c("windows", "darwin", "linux", "sunos"))]
-
 #' @export
 #' @rdname checkOS
 check_os = checkOS
@@ -51,5 +47,5 @@ test_os = testOS
 #' @rdname checkOS
 expect_os = function(os, info = NULL, label = NULL) {
   res = checkOS(os)
-  makeExpectation(OS, res, info, label = label %??% "Operating System")
+  makeExpectation(.OS, res, info, label = label %??% "Operating System")
 }
